package com.googlecode.marrowboy.assertionresult;

import java.util.Collection;
import java.util.LinkedHashMap;
import java.util.Map;

import com.googlecode.marrowboy.utilities.StringHelper;

/**
 * Holds details of test classes in {@link ClassResult} objects, and reporting
 * methods for counting different kinds of assertions.
 * 
 * @author mjg
 */
public class TestRunResult {

	private final Map<String, ClassResult> classResults;
	private final StringHelper stringHelper;

	public TestRunResult() {
		classResults = new LinkedHashMap<String, ClassResult>();
		stringHelper = new StringHelper();
	}

	public AssertionResult logMessageFromStackTraceElement(StackTraceElement stackTraceElement, String reason, String actualString, String matcherDescription, boolean wasSuccessful) {

		String className = stringHelper.extractClassName(stackTraceElement);
		String methodName = stringHelper.extractMethodName(stackTraceElement);
		AssertionResult assertionResult = new AssertionResult(reason, actualString, matcherDescription, wasSuccessful);

		assertionResult.setFilename(stackTraceElement.getFileName());
		assertionResult.setLineNumber(stackTraceElement.getLineNumber());

		ClassResult classResult = getClassResult(className);
		MethodResult methodResult = classResult.getMethodResult(methodName);
		methodResult.addAssertion(assertionResult);

		return assertionResult;

	}

	public Collection<ClassResult> getClassResults() {
		return classResults.values();
	}

	private ClassResult getClassResult(String className) {
		if (classResults.get(className) == null) {
			classResults.put(className, new ClassResult(className));
		}

		return classResults.get(className);
	}

	public int getPassCount() {

		int passCount = 0;

		for (ClassResult classResult : classResults.values()) {
			passCount += classResult.getPassCount();
		}

		return passCount;
	}

	public int getFailCount() {
		int failCount = 0;

		for (ClassResult classResult : classResults.values()) {
			failCount += classResult.getFailCount();
		}

		return failCount;
	}

	public int getTotalCount() {
		int totalCount = 0;

		for (ClassResult classResult : classResults.values()) {
			totalCount += classResult.getTotalCount();
		}

		return totalCount;
	}

}
